(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    119453,       2168]
NotebookOptionsPosition[    114733,       2020]
NotebookOutlinePosition[    115232,       2039]
CellTagsIndexPosition[    115189,       2036]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Information", "Section",
 CellChangeTimes->{{3.519665040029275*^9, 3.5196650407863183`*^9}}],

Cell[TextData[{
 "This package extends the basic functions of the HDF5` package from the \
basic functions of the HDF5group.org (",
 ButtonBox["http://www.hdfgroup.org/HDF5/doc/RM/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.hdfgroup.org/HDF5/doc/RM/"], None},
  ButtonNote->"http://www.hdfgroup.org/HDF5/doc/RM/"],
 ") into a more ",
 StyleBox["Mathematica-",
  FontSlant->"Italic"],
 "oriented syntax. One main purpose of these extended functions is to bury \
the three-line NETNew[...] formulation that is needed for some function calls \
into a single convenient function (cf. H5SExtendGetSimpleExtentDims)."
}], "Text",
 CellChangeTimes->{{3.519651472628852*^9, 3.5196515189609327`*^9}, {
  3.519651553093793*^9, 3.519651623231516*^9}, {3.5196525254435005`*^9, 
  3.519652571557182*^9}}],

Cell[TextData[{
 "Prepared 14 July 2011 by Scot Martin for Windows 7, 64-bit, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " version 8.0.1. Email: scot_martin@harvard.edu."
}], "Text",
 CellChangeTimes->{{3.5192900627995815`*^9, 3.519290073040167*^9}, {
   3.519292549013785*^9, 3.519292559290373*^9}, {3.519651457418825*^9, 
   3.51965146581164*^9}, 3.5196515456057796`*^9}],

Cell[TextData[{
 ButtonBox["http://www.hdfgroup.org/HDF5/doc/RM/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.hdfgroup.org/HDF5/doc/RM/"], None},
  ButtonNote->"http://www.hdfgroup.org/HDF5/doc/RM/"],
 "\n",
 ButtonBox["http://www.hdfgroup.org/HDF5/doc/RM/RM_H5Front.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.hdfgroup.org/HDF5/doc/RM/RM_H5Front.html"], None},
  ButtonNote->"http://www.hdfgroup.org/HDF5/doc/RM/RM_H5Front.html"],
 "\nSource code: ",
 ButtonBox["http://www.hdfgroup.org/ftp/HDF5/current/src/unpacked/src/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.hdfgroup.org/ftp/HDF5/current/src/unpacked/src/"], None},
  ButtonNote->"http://www.hdfgroup.org/ftp/HDF5/current/src/unpacked/src/"]
}], "Text",
 CellChangeTimes->{{3.519204574069906*^9, 3.5192046043556385`*^9}, {
  3.5192048157717304`*^9, 3.519204834786818*^9}, {3.5192057745415688`*^9, 
  3.5192057875533133`*^9}, {3.519220971218769*^9, 3.5192209824754133`*^9}, {
  3.5194182174374576`*^9, 3.5194182361305265`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Package", "Section",
 CellChangeTimes->{{3.519291813813734*^9, 3.519291824028318*^9}}],

Cell[CellGroupData[{

Cell["BeginPackage Context[...]", "Subsection",
 CellChangeTimes->{{3.51929183718307*^9, 3.5192918414883165`*^9}}],

Cell[BoxData[
 RowBox[{"BeginPackage", "[", 
  RowBox[{"\"\<HDF5Extend`\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"\"\<HDF5`\>\"", ",", "\"\<NETLink`\>\""}], "}"}]}], 
  "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.457546165609375*^9, 3.457546171265625*^9}, {
   3.457546207015625*^9, 3.457546220796875*^9}, {3.45799610640625*^9, 
   3.45799611634375*^9}, {3.468963528828125*^9, 3.4689635290625*^9}, {
   3.4823496125557427`*^9, 3.48234961459686*^9}, 3.489017891677415*^9, {
   3.5186009153340993`*^9, 3.518600938016539*^9}, {3.5186010187466807`*^9, 
   3.5186010191366816`*^9}, {3.5186011517993145`*^9, 3.518601152251715*^9}, {
   3.5192915927500896`*^9, 3.519291593252118*^9}, 3.5192916330783963`*^9, {
   3.519297102825248*^9, 3.519297111550747*^9}, {3.5196516286759253`*^9, 
   3.5196516341827354`*^9}, {3.5196523032211103`*^9, 3.519652306996317*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Definitions", "Subsection",
 CellChangeTimes->{{3.5192918020820627`*^9, 3.5192918044061956`*^9}}],

Cell[BoxData[
 RowBox[{"$HDF5ExtendPackageVersion", "=", "\"\<V1.00\>\""}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.457546165609375*^9, 3.457546171265625*^9}, {
   3.457546207015625*^9, 3.457546220796875*^9}, {3.45799610640625*^9, 
   3.45799611634375*^9}, {3.468963528828125*^9, 3.4689635290625*^9}, {
   3.4823496125557427`*^9, 3.48234961459686*^9}, 3.489017891677415*^9, {
   3.5186009153340993`*^9, 3.518600938016539*^9}, {3.5186010187466807`*^9, 
   3.5186010191366816`*^9}, {3.5186011517993145`*^9, 3.518601152251715*^9}, {
   3.5192915927500896`*^9, 3.519291593252118*^9}, {3.519297166116868*^9, 
   3.519297166209873*^9}, {3.519297210639415*^9, 3.5192972109494324`*^9}, {
   3.5193343486331544`*^9, 3.51933434994823*^9}, {3.519334391273593*^9, 
   3.519334398494006*^9}, {3.5193344883511457`*^9, 3.519334489964238*^9}, 
   3.5193347104768505`*^9, {3.5193347753775625`*^9, 3.51933479805986*^9}, {
   3.519334872955144*^9, 3.5193348782484465`*^9}, {3.519651637801942*^9, 
   3.519651639595945*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Usage Statements", "Subsection",
 CellChangeTimes->{{3.519333913510267*^9, 3.519333916273425*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5ExtendGetUlibVersion", "::", "usage"}], "=", 
  "\[IndentingNewLine]", 
  "\"\<H5ExtendGetUlibVersion[] returns the version of the H5 library as a \
list of {major, minor, revision}.\>\""}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.5193386082157884`*^9, 3.5193386480800686`*^9}, 
   3.519339201088699*^9, {3.5196519482736874`*^9, 3.519652003606984*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5SExtendGetSimpleExtentDims", "::", "usage"}], "=", 
  "\[IndentingNewLine]", 
  "\"\<H5SExtendGetSimpleExtentDims[\\\"DataSpaceID\\\"] returns as a list \
the dimensions of the DataSpaceID.\>\""}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.5193386082157884`*^9, 3.5193386480800686`*^9}, 
   3.519339201088699*^9, {3.5196519482736874`*^9, 3.519652003606984*^9}, {
   3.519652161822462*^9, 3.5196521840213013`*^9}, 3.5196523663388214`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5DExtendRead", "::", "usage"}], "=", "\[IndentingNewLine]", 
  "\"\<H5DExtendRead[\\\"DataSpaceID\\\", \\\"MemoryTypeID\\\", \
\\\"MemorySpaceID\\\", \\\"FileSpaceID\\\", \\\"xferPListID\\\", \
\\\"Dimensions\\\"] reads data from a file. The first 5 arguments are as \
defined for H5Dread. The \\\"Dimensions\\\" argument should be a list of \
dimensions of the object to be read, e.g., \\\"{10}\\\" for a rank 1 data set \
of length 10, \\\"{10,5}\\\" for a rank 2 data set of dimensions 10 by 5, and \
so forth. This function takes the option \\\"DataType\\\", which is Integer32 \
by default. Allowed DataTypes include Byte, Integer32, Integer64, \
SingleFloat, and DoubleFloat. (Other allowed values can be easily added by \
additional programming of H5Dread in \\\"HDF5`\\\" and of H5DExtendRead in \\\
\"HDF5Extend`\\\".)\>\""}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.5193386082157884`*^9, 3.5193386480800686`*^9}, 
   3.519339201088699*^9, {3.5196519482736874`*^9, 3.519652003606984*^9}, {
   3.519652161822462*^9, 3.5196521840213013`*^9}, 3.5196523663388214`*^9, {
   3.519653839693652*^9, 3.519653873691597*^9}, {3.51965390661548*^9, 
   3.51965407881833*^9}, {3.519654423357036*^9, 3.5196544236580534`*^9}, {
   3.5196612966441655`*^9, 3.5196613174293547`*^9}, {3.5197229290244255`*^9, 
   3.519722932351616*^9}, {3.519815887076322*^9, 3.5198159040102906`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5DExtendWrite", "::", "usage"}], "=", "\[IndentingNewLine]", 
  "\"\<H5DExtendRead[\\\"DataSpaceID\\\", \\\"MemoryTypeID\\\", \
\\\"MemorySpaceID\\\", \\\"FileSpaceID\\\", \\\"xferPListID\\\", \
\\\"Data\\\"] writes data to a file. The first 5 arguments are as defined for \
H5Dwrite. The \\\"Data\\\" argument should be a list or a list of lists, \
depending on dimensions of data. This function takes the option \
\\\"DataType\\\", which is Integer32 by default. Other allowed values are \
Byte, SingleFloat, and DoubleFloat. (Other allowed values can be easily added \
by additional programming of H5Dwrite in \\\"HDF5`\\\" and of H5DExtendWrite \
in \\\"HDF5Extend`\\\".)\>\""}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.5193386082157884`*^9, 3.5193386480800686`*^9}, 
   3.519339201088699*^9, {3.5196519482736874`*^9, 3.519652003606984*^9}, {
   3.519652161822462*^9, 3.5196521840213013`*^9}, 3.5196523663388214`*^9, {
   3.519653839693652*^9, 3.519653873691597*^9}, {3.51965390661548*^9, 
   3.51965407881833*^9}, {3.519654423357036*^9, 3.5196544236580534`*^9}, {
   3.519661241237996*^9, 3.5196613218566074`*^9}, {3.5197229377989273`*^9, 
   3.5197229412581253`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5DExtendOpen", "::", "usage"}], "=", "\[IndentingNewLine]", 
  "\"\<H5DExtendOpen[{\\\"dataSetIDsymbol\\\" = H5Dopen[....]}, body] sets \
the dataSetIDsymbol and then runs the body. The purpose of this function is \
that it provides an automatic H5Dclose[dataSetIDsymbol] after executing body. \
The return value is that of the body.\>\""}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.5193386082157884`*^9, 3.5193386480800686`*^9}, 
   3.519339201088699*^9, {3.5196519482736874`*^9, 3.519652003606984*^9}, {
   3.519652161822462*^9, 3.5196521840213013`*^9}, 3.5196523663388214`*^9, {
   3.519653839693652*^9, 3.519653873691597*^9}, {3.51965390661548*^9, 
   3.51965407881833*^9}, {3.519654423357036*^9, 3.5196544236580534`*^9}, {
   3.519661241237996*^9, 3.5196613623299227`*^9}, {3.5196613986279984`*^9, 
   3.5196615544579115`*^9}, {3.5196615844706283`*^9, 3.5196615868857665`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5FExtendOpen", "::", "usage"}], "=", "\[IndentingNewLine]", 
  "\"\<H5FExtendOpen[{\\\"fileIDsymbol\\\" = H5Fopen[....]}, body] sets the \
fileIDsymbol and then runs the body. The purpose of this function is that it \
provides an automatic H5Fclose[fileIDsymbol] after executing body. The return \
value is that of the body.\>\""}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.5193386082157884`*^9, 3.5193386480800686`*^9}, 
   3.519339201088699*^9, {3.5196519482736874`*^9, 3.519652003606984*^9}, {
   3.519652161822462*^9, 3.5196521840213013`*^9}, 3.5196523663388214`*^9, {
   3.519653839693652*^9, 3.519653873691597*^9}, {3.51965390661548*^9, 
   3.51965407881833*^9}, {3.519654423357036*^9, 3.5196544236580534`*^9}, {
   3.519661241237996*^9, 3.5196613623299227`*^9}, {3.5196613986279984`*^9, 
   3.5196614808347006`*^9}, {3.519661589027889*^9, 3.519661591424026*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5GExtendOpen", "::", "usage"}], "=", "\[IndentingNewLine]", 
  "\"\<H5GExtendOpen[{\\\"groupIDsymbol\\\" = H5Gopen[....]}, body] sets the \
groupIDsymbol and then runs the body. The purpose of this function is that it \
provides an automatic H5Dclose[dataSetIDsymbol] after executing body. The \
return value is that of the body.\>\""}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.5193386082157884`*^9, 3.5193386480800686`*^9}, 
   3.519339201088699*^9, {3.5196519482736874`*^9, 3.519652003606984*^9}, {
   3.519652161822462*^9, 3.5196521840213013`*^9}, 3.5196523663388214`*^9, {
   3.519653839693652*^9, 3.519653873691597*^9}, {3.51965390661548*^9, 
   3.51965407881833*^9}, {3.519654423357036*^9, 3.5196544236580534`*^9}, {
   3.519661241237996*^9, 3.5196613623299227`*^9}, {3.5196613986279984`*^9, 
   3.5196615958562794`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5GExtendGetNumObjs", "::", "usage"}], "=", "\[IndentingNewLine]", 
  "\"\<H5GExtendGetNumObjs[\\\"GroupOrFileID\\\"] returns the number of \
objects at one node of the GroupOrFileID.\>\""}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.5193386082157884`*^9, 3.5193386480800686`*^9}, 
   3.519339201088699*^9, {3.5196519482736874`*^9, 3.519652003606984*^9}, {
   3.519652161822462*^9, 3.5196521840213013`*^9}, 3.5196523663388214`*^9, {
   3.519653839693652*^9, 3.519653873691597*^9}, {3.51965390661548*^9, 
   3.51965407881833*^9}, {3.519654423357036*^9, 3.5196544236580534`*^9}, {
   3.519661241237996*^9, 3.5196613623299227`*^9}, {3.5196613986279984`*^9, 
   3.5196615958562794`*^9}, {3.519832710677577*^9, 3.519832769352933*^9}, {
   3.5198328391879272`*^9, 3.519832841028033*^9}, {3.5198346680835342`*^9, 
   3.51983466871257*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5GExtendGetObjNameByIndex", "::", "usage"}], "=", 
  "\[IndentingNewLine]", 
  "\"\<H5GExtendGetObjNameByIndex[\\\"GroupOrFileID\\\", \\\"Index\\\"] \
returns the String name for the indicated Index of the \
GroupOrFileID.\>\""}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.5193386082157884`*^9, 3.5193386480800686`*^9}, 
   3.519339201088699*^9, {3.5196519482736874`*^9, 3.519652003606984*^9}, {
   3.519652161822462*^9, 3.5196521840213013`*^9}, 3.5196523663388214`*^9, {
   3.519653839693652*^9, 3.519653873691597*^9}, {3.51965390661548*^9, 
   3.51965407881833*^9}, {3.519654423357036*^9, 3.5196544236580534`*^9}, {
   3.519661241237996*^9, 3.5196613623299227`*^9}, {3.5196613986279984`*^9, 
   3.5196615958562794`*^9}, {3.519832710677577*^9, 3.519832769352933*^9}, {
   3.5198328391879272`*^9, 3.519832841028033*^9}, {3.5198339692245617`*^9, 
   3.519834086564273*^9}, {3.5198346831743975`*^9, 3.5198346946580544`*^9}, {
   3.519849308217902*^9, 3.5198493135922093`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5AExtendGetName", "::", "usage"}], "=", "\[IndentingNewLine]", 
  "\"\<H5AExtendGetName[\\\"AttributeID\\\"] returns the String name for the \
indicated AttributeID.\>\""}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.5193386082157884`*^9, 3.5193386480800686`*^9}, 
   3.519339201088699*^9, {3.5196519482736874`*^9, 3.519652003606984*^9}, {
   3.519652161822462*^9, 3.5196521840213013`*^9}, 3.5196523663388214`*^9, {
   3.519653839693652*^9, 3.519653873691597*^9}, {3.51965390661548*^9, 
   3.51965407881833*^9}, {3.519654423357036*^9, 3.5196544236580534`*^9}, {
   3.519661241237996*^9, 3.5196613623299227`*^9}, {3.5196613986279984`*^9, 
   3.5196615958562794`*^9}, {3.519832710677577*^9, 3.519832769352933*^9}, {
   3.5198328391879272`*^9, 3.519832841028033*^9}, {3.5198339692245617`*^9, 
   3.519834086564273*^9}, {3.5198346831743975`*^9, 3.5198346946580544`*^9}, 
   3.5198489854484406`*^9, {3.519849075966618*^9, 3.5198490971108274`*^9}, 
   3.519849323404771*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5AExtendRead", "::", "usage"}], "=", "\[IndentingNewLine]", 
  "\"\<H5AExtendRead[\\\"AttributeID\\\", \\\"MemoryTypeID\\\", \
\\\"Dimensions\\\"] reads the value of an attribute. \\\"Dimensions\\\" is \
typically {1} for most common applications. This function takes the option \\\
\"DataType\\\", which is Integer32 by default. Allowed DataTypes include \
Byte, Integer32, Integer64, SingleFloat, and DoubleFloat.\>\""}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.5193386082157884`*^9, 3.5193386480800686`*^9}, 
   3.519339201088699*^9, {3.5196519482736874`*^9, 3.519652003606984*^9}, {
   3.519652161822462*^9, 3.5196521840213013`*^9}, 3.5196523663388214`*^9, {
   3.519653839693652*^9, 3.519653873691597*^9}, {3.51965390661548*^9, 
   3.51965407881833*^9}, {3.519654423357036*^9, 3.5196544236580534`*^9}, {
   3.519661241237996*^9, 3.5196613623299227`*^9}, {3.5196613986279984`*^9, 
   3.5196615958562794`*^9}, {3.519832710677577*^9, 3.519832769352933*^9}, {
   3.5198328391879272`*^9, 3.519832841028033*^9}, {3.5198339692245617`*^9, 
   3.519834086564273*^9}, {3.5198346831743975`*^9, 3.5198346946580544`*^9}, 
   3.5198489854484406`*^9, {3.519849075966618*^9, 3.5198490971108274`*^9}, 
   3.519849323404771*^9, {3.519854977826185*^9, 3.5198549781982064`*^9}, {
   3.5198552000318947`*^9, 3.5198552777763414`*^9}, {3.519855332975498*^9, 
   3.519855333302517*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Begin Private Context[...]", "Subsection",
 CellChangeTimes->{{3.51929183718307*^9, 3.5192918414883165`*^9}, {
  3.519662043830902*^9, 3.519662045064973*^9}}],

Cell[BoxData[
 RowBox[{"Begin", "[", "\"\<Private`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.457546165609375*^9, 3.457546171265625*^9}, {
   3.457546207015625*^9, 3.457546220796875*^9}, {3.45799610640625*^9, 
   3.45799611634375*^9}, {3.468963528828125*^9, 3.4689635290625*^9}, {
   3.4823496125557427`*^9, 3.48234961459686*^9}, 3.489017891677415*^9, {
   3.5186009153340993`*^9, 3.518600938016539*^9}, {3.5186010187466807`*^9, 
   3.5186010191366816`*^9}, {3.5186011517993145`*^9, 3.518601152251715*^9}, {
   3.5192915927500896`*^9, 3.519291593252118*^9}, 3.5192916330783963`*^9, {
   3.519297102825248*^9, 3.519297111550747*^9}, {3.5196516286759253`*^9, 
   3.5196516341827354`*^9}, {3.5196523032211103`*^9, 3.519652306996317*^9}, {
   3.519662046955081*^9, 3.51966205743468*^9}}],

Cell[CellGroupData[{

Cell["H5", "Subsubsection",
 CellChangeTimes->{{3.5192044912381682`*^9, 3.5192044914801817`*^9}}],

Cell["H5EXTENDGETULIBVERSION", "Text",
 CellChangeTimes->{{3.5196602954469004`*^9, 3.5196602993621244`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5ExtendGetUlibVersion", "[", "]"}], ":=", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"major", "=", 
      RowBox[{"minor", "=", 
       RowBox[{"revision", "=", "0"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"CompoundExpression", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"H5getUlibversion", "[", 
       RowBox[{"major", ",", "minor", ",", "revision"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", "return", "*)"}], " ", 
      RowBox[{"{", 
       RowBox[{"major", ",", "minor", ",", "revision"}], "}"}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5191733398934135`*^9, 3.519173365854898*^9}, {
   3.519173446170492*^9, 3.51917344718355*^9}, {3.519173714830858*^9, 
   3.5191737306227617`*^9}, {3.5191739405427685`*^9, 3.51917397274761*^9}, {
   3.519176894147705*^9, 3.519176894256711*^9}, 3.5192053347354136`*^9, 
   3.519224813284523*^9, {3.5192248527497797`*^9, 3.5192248528837876`*^9}, 
   3.5192920674302397`*^9, 3.51929411701847*^9, 3.5192970476020894`*^9, {
   3.519315739314762*^9, 3.5193157412418723`*^9}, {3.5196517309029055`*^9, 
   3.5196518027722316`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["H5A", "Subsubsection",
 CellChangeTimes->{{3.5192044912381682`*^9, 3.5192044914801817`*^9}, 
   3.519290399780856*^9}],

Cell["H5AExtendGetName", "Text",
 CellChangeTimes->{{3.5196602954469004`*^9, 3.5196602993621244`*^9}, {
   3.5198326026253967`*^9, 3.51983260285441*^9}, {3.5198326892213497`*^9, 
   3.519832692426533*^9}, 3.5198328461423254`*^9, {3.519833958268935*^9, 
   3.5198339657833652`*^9}, {3.5198340174583206`*^9, 3.519834018644388*^9}, {
   3.51984895885592*^9, 3.5198489616490793`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5AExtendGetName", "[", "attributeID_Integer", "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"NETBlock", "[", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"size", "=", 
       RowBox[{
        RowBox[{"H5AgetName", "[", 
         RowBox[{"attributeID", ",", "0", ",", "Null"}], "]"}], "+", "1"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"buffer", "=", 
         RowBox[{"NETNew", "[", 
          RowBox[{"\"\<System.Text.StringBuilder\>\"", ",", "size"}], "]"}]}],
         "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"CompoundExpression", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"H5AgetName", "[", 
          RowBox[{"attributeID", ",", "size", ",", "buffer"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", "return", "*)"}], "  ", 
         RowBox[{"buffer", "@", 
          RowBox[{"ToString", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
      "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5191733398934135`*^9, 3.519173365854898*^9}, {
   3.519173446170492*^9, 3.51917344718355*^9}, {3.519173714830858*^9, 
   3.5191737306227617`*^9}, {3.5191739405427685`*^9, 3.51917397274761*^9}, {
   3.519176894147705*^9, 3.519176894256711*^9}, 3.5192053347354136`*^9, 
   3.519224813284523*^9, {3.5192248527497797`*^9, 3.5192248528837876`*^9}, 
   3.5192920674302397`*^9, 3.51929411701847*^9, 3.5192970476020894`*^9, {
   3.519315739314762*^9, 3.5193157412418723`*^9}, {3.5196517309029055`*^9, 
   3.5196518027722316`*^9}, {3.519832626790779*^9, 3.5198326864741926`*^9}, 
   3.5198328450482626`*^9, 3.519833959281993*^9, {3.5198340205965*^9, 
   3.519834024329714*^9}, {3.519834095042758*^9, 3.519834170849094*^9}, {
   3.519848951959525*^9, 3.5198489566687946`*^9}, {3.5198490089877872`*^9, 
   3.5198490653140087`*^9}, {3.5198491186870613`*^9, 3.519849119922132*^9}, 
   3.5198491780594573`*^9, {3.5198492669485416`*^9, 3.519849267198556*^9}}],

Cell["H5AEXTENDREAD", "Text",
 CellChangeTimes->{{3.5196602867034*^9, 3.5196602906866283`*^9}, 
   3.519854903358926*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "H5AExtendRead", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"\"\<DataType\>\"", "\[Rule]", "Integer32"}], "}"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.51934407062022*^9, 3.519344120024046*^9}, {
   3.51934615413139*^9, 3.519346196527815*^9}, {3.5193463071891446`*^9, 
   3.519346553786249*^9}, {3.5194247842480574`*^9, 3.5194247873542356`*^9}, {
   3.5194248180309896`*^9, 3.5194248370840797`*^9}, 3.519427366309743*^9, {
   3.519653122175749*^9, 3.519653129819762*^9}, 3.5198549055300503`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"H5AExtendRead", "[", 
    RowBox[{
    "attributeID_Integer", ",", "memoryTypeID_Integer", ",", 
     "dimensions_List", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"NETBlock", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"readDataObject", ",", "dataAsVector", ",", "dataAsMatrix"}], 
       "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
      "CompoundExpression", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "make", " ", "the", " ", "correct", " ", "buffer", " ", "type", " ", 
         "and", " ", "size", " ", "for", " ", "reading", " ", "in", " ", 
         "data", " ", "as", " ", "one", " ", "long", " ", "vector"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Switch", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"OptionValue", "[", "\"\<DataType\>\"", "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "Byte", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"readDataObject", "=", 
           RowBox[{"NETNew", "[", 
            RowBox[{"\"\<System.Byte[]\>\"", ",", 
             RowBox[{"Times", "@@", "dimensions"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "Integer32", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"readDataObject", "=", 
           RowBox[{"NETNew", "[", 
            RowBox[{"\"\<System.Int32[]\>\"", ",", 
             RowBox[{"Times", "@@", "dimensions"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "Integer64", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"readDataObject", "=", 
           RowBox[{"NETNew", "[", 
            RowBox[{"\"\<System.Int64[]\>\"", ",", 
             RowBox[{"Times", "@@", "dimensions"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "SingleFloat", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"readDataObject", "=", 
           RowBox[{"NETNew", "[", 
            RowBox[{"\"\<System.Single[]\>\"", ",", 
             RowBox[{"Times", "@@", "dimensions"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "DoubleFloat", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"readDataObject", "=", 
           RowBox[{"NETNew", "[", 
            RowBox[{"\"\<System.Double[]\>\"", ",", 
             RowBox[{"Times", "@@", "dimensions"}]}], "]"}]}]}], 
         "\[IndentingNewLine]", "]"}], 
        RowBox[{"(*", 
         RowBox[{"close", " ", "Switch"}], "*)"}], ",", "\[IndentingNewLine]",
         "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "read", " ", "in", " ", "the", " ", "data", " ", "to", " ", "the", 
          " ", "buffer"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"H5Aread", "[", 
          RowBox[{"OptionValue", "[", "\"\<DataType\>\"", "]"}], "]"}], "[", 
         RowBox[{"attributeID", ",", "memoryTypeID", ",", "readDataObject"}], 
         "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "data", " ", "is", " ", "read", " ", "in", " ", "as", " ", "one", 
          " ", "long", " ", 
          RowBox[{"List", "[", "..", "]"}]}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"dataAsVector", "=", 
         RowBox[{"NETObjectToExpression", "[", "readDataObject", "]"}]}], ",",
         "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "use", " ", "this", " ", "fancy", " ", "function", " ", "to", " ", 
          "get", " ", "data", " ", "back", " ", "into", " ", "lists", " ", 
          "of", " ", "lists"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"dataAsMatrix", "=", 
         RowBox[{"Fold", "[", 
          RowBox[{"Partition", ",", "dataAsVector", ",", 
           RowBox[{"Reverse", "@", 
            RowBox[{"Rest", "@", "dimensions"}]}]}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}]}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{"close", " ", "CompoundExpression"}], " ", "*)"}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{"close", " ", "Module"}], " ", "*)"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "]"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"close", " ", "NETBlock"}], " ", "*)"}], 
  "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5191733398934135`*^9, 3.519173365854898*^9}, {
   3.519173446170492*^9, 3.51917344718355*^9}, {3.519173714830858*^9, 
   3.5191737306227617`*^9}, {3.5191739405427685`*^9, 3.51917397274761*^9}, {
   3.519176894147705*^9, 3.519176894256711*^9}, 3.5192053347354136`*^9, 
   3.519224813284523*^9, {3.5192248527497797`*^9, 3.5192248528837876`*^9}, 
   3.5192920674302397`*^9, 3.51929411701847*^9, 3.5192970476020894`*^9, {
   3.519315739314762*^9, 3.5193157412418723`*^9}, {3.5196517309029055`*^9, 
   3.5196518027722316`*^9}, {3.5196520714671035`*^9, 3.519652135895217*^9}, {
   3.519652452778573*^9, 3.5196524556645784`*^9}, {3.519653090382893*^9, 
   3.5196530935340986`*^9}, {3.5196531791314487`*^9, 3.519653250173974*^9}, {
   3.5196532810152283`*^9, 3.5196532980192575`*^9}, {3.5196533325806475`*^9, 
   3.5196538112690268`*^9}, {3.5196538853022614`*^9, 3.519653890852578*^9}, {
   3.519654660230584*^9, 3.5196546604445963`*^9}, 3.519659549731248*^9, {
   3.5197228948944736`*^9, 3.519722903382959*^9}, {3.519815861251845*^9, 
   3.519815869788333*^9}, {3.5198549093292675`*^9, 3.5198549442672653`*^9}, {
   3.5198550282940717`*^9, 3.519855033299358*^9}, {3.5198551228534803`*^9, 
   3.519855162273735*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["H5D", "Subsubsection",
 CellChangeTimes->{{3.519204542239085*^9, 3.519204543245143*^9}, 
   3.5192170693915977`*^9}],

Cell["H5DEXTENDREAD", "Text",
 CellChangeTimes->{{3.5196602867034*^9, 3.5196602906866283`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "H5DExtendRead", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"\"\<DataType\>\"", "\[Rule]", "Integer32"}], "}"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.51934407062022*^9, 3.519344120024046*^9}, {
   3.51934615413139*^9, 3.519346196527815*^9}, {3.5193463071891446`*^9, 
   3.519346553786249*^9}, {3.5194247842480574`*^9, 3.5194247873542356`*^9}, {
   3.5194248180309896`*^9, 3.5194248370840797`*^9}, 3.519427366309743*^9, {
   3.519653122175749*^9, 3.519653129819762*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"H5DExtendRead", "[", 
    RowBox[{
    "dataSetID_Integer", ",", "memoryTypeID_Integer", ",", 
     "memorySpaceID_Integer", ",", "fileSpaceID_Integer", ",", 
     "xferPListID_Integer", ",", "dimensions_List", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"NETBlock", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"readDataObject", ",", "dataAsVector", ",", "dataAsMatrix"}], 
       "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
      "CompoundExpression", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "make", " ", "the", " ", "correct", " ", "buffer", " ", "type", " ", 
         "and", " ", "size", " ", "for", " ", "reading", " ", "in", " ", 
         "data", " ", "as", " ", "one", " ", "long", " ", "vector"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Switch", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"OptionValue", "[", "\"\<DataType\>\"", "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "Byte", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"readDataObject", "=", 
           RowBox[{"NETNew", "[", 
            RowBox[{"\"\<System.Byte[]\>\"", ",", 
             RowBox[{"Times", "@@", "dimensions"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "Integer32", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"readDataObject", "=", 
           RowBox[{"NETNew", "[", 
            RowBox[{"\"\<System.Int32[]\>\"", ",", 
             RowBox[{"Times", "@@", "dimensions"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "Integer64", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"readDataObject", "=", 
           RowBox[{"NETNew", "[", 
            RowBox[{"\"\<System.Int64[]\>\"", ",", 
             RowBox[{"Times", "@@", "dimensions"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "SingleFloat", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"readDataObject", "=", 
           RowBox[{"NETNew", "[", 
            RowBox[{"\"\<System.Single[]\>\"", ",", 
             RowBox[{"Times", "@@", "dimensions"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "DoubleFloat", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"readDataObject", "=", 
           RowBox[{"NETNew", "[", 
            RowBox[{"\"\<System.Double[]\>\"", ",", 
             RowBox[{"Times", "@@", "dimensions"}]}], "]"}]}]}], 
         "\[IndentingNewLine]", "]"}], 
        RowBox[{"(*", 
         RowBox[{"close", " ", "Switch"}], "*)"}], ",", "\[IndentingNewLine]",
         "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "read", " ", "in", " ", "the", " ", "data", " ", "to", " ", "the", 
          " ", "buffer"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"H5Dread", "[", 
          RowBox[{"OptionValue", "[", "\"\<DataType\>\"", "]"}], "]"}], "[", 
         RowBox[{
         "dataSetID", ",", "memoryTypeID", ",", "memorySpaceID", ",", 
          "fileSpaceID", ",", "xferPListID", ",", "readDataObject"}], "]"}], 
        ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "data", " ", "is", " ", "read", " ", "in", " ", "as", " ", "one", 
          " ", "long", " ", 
          RowBox[{"List", "[", "..", "]"}]}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"dataAsVector", "=", 
         RowBox[{"NETObjectToExpression", "[", "readDataObject", "]"}]}], ",",
         "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "use", " ", "this", " ", "fancy", " ", "function", " ", "to", " ", 
          "get", " ", "data", " ", "back", " ", "into", " ", "lists", " ", 
          "of", " ", "lists"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"dataAsMatrix", "=", 
         RowBox[{"Fold", "[", 
          RowBox[{"Partition", ",", "dataAsVector", ",", 
           RowBox[{"Reverse", "@", 
            RowBox[{"Rest", "@", "dimensions"}]}]}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}]}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{"close", " ", "CompoundExpression"}], " ", "*)"}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{"close", " ", "Module"}], " ", "*)"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "]"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"close", " ", "NETBlock"}], " ", "*)"}], 
  "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5191733398934135`*^9, 3.519173365854898*^9}, {
   3.519173446170492*^9, 3.51917344718355*^9}, {3.519173714830858*^9, 
   3.5191737306227617`*^9}, {3.5191739405427685`*^9, 3.51917397274761*^9}, {
   3.519176894147705*^9, 3.519176894256711*^9}, 3.5192053347354136`*^9, 
   3.519224813284523*^9, {3.5192248527497797`*^9, 3.5192248528837876`*^9}, 
   3.5192920674302397`*^9, 3.51929411701847*^9, 3.5192970476020894`*^9, {
   3.519315739314762*^9, 3.5193157412418723`*^9}, {3.5196517309029055`*^9, 
   3.5196518027722316`*^9}, {3.5196520714671035`*^9, 3.519652135895217*^9}, {
   3.519652452778573*^9, 3.5196524556645784`*^9}, {3.519653090382893*^9, 
   3.5196530935340986`*^9}, {3.5196531791314487`*^9, 3.519653250173974*^9}, {
   3.5196532810152283`*^9, 3.5196532980192575`*^9}, {3.5196533325806475`*^9, 
   3.5196538112690268`*^9}, {3.5196538853022614`*^9, 3.519653890852578*^9}, {
   3.519654660230584*^9, 3.5196546604445963`*^9}, 3.519659549731248*^9, {
   3.5197228948944736`*^9, 3.519722903382959*^9}, {3.519815861251845*^9, 
   3.519815869788333*^9}}],

Cell["H5DEXTENDWRITE", "Text",
 CellChangeTimes->{{3.5196602693714085`*^9, 3.5196602725295897`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "H5DExtendWrite", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"\"\<DataType\>\"", "\[Rule]", "Integer32"}], "}"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.51934407062022*^9, 3.519344120024046*^9}, {
   3.51934615413139*^9, 3.519346196527815*^9}, {3.5193463071891446`*^9, 
   3.519346553786249*^9}, {3.5194247842480574`*^9, 3.5194247873542356`*^9}, {
   3.5194248180309896`*^9, 3.5194248370840797`*^9}, 3.519427366309743*^9, {
   3.519653122175749*^9, 3.519653129819762*^9}, {3.519660130910489*^9, 
   3.5196601313655157`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"H5DExtendWrite", "[", 
    RowBox[{
    "dataSetID_Integer", ",", "memoryTypeID_Integer", ",", 
     "memorySpaceID_Integer", ",", "fileSpaceID_Integer", ",", 
     "xferPListID_Integer", ",", "data_List", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "use", " ", "the", " ", "correct", " ", "function", " ", "for", " ", 
     "the", " ", "type", " ", "of", " ", "data"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"H5Dwrite", "[", 
     RowBox[{"OptionValue", "[", "\"\<DataType\>\"", "]"}], "]"}], "[", 
    RowBox[{
    "dataSetID", ",", "memoryTypeID", ",", "memorySpaceID", ",", 
     "fileSpaceID", ",", "xferPListID", ",", 
     RowBox[{"Flatten", "@", "data"}]}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5191733398934135`*^9, 3.519173365854898*^9}, {
   3.519173446170492*^9, 3.51917344718355*^9}, {3.519173714830858*^9, 
   3.5191737306227617`*^9}, {3.5191739405427685`*^9, 3.51917397274761*^9}, {
   3.519176894147705*^9, 3.519176894256711*^9}, 3.5192053347354136`*^9, 
   3.519224813284523*^9, {3.5192248527497797`*^9, 3.5192248528837876`*^9}, 
   3.5192920674302397`*^9, 3.51929411701847*^9, 3.5192970476020894`*^9, {
   3.519315739314762*^9, 3.5193157412418723`*^9}, {3.5196517309029055`*^9, 
   3.5196518027722316`*^9}, {3.5196520714671035`*^9, 3.519652135895217*^9}, {
   3.519652452778573*^9, 3.5196524556645784`*^9}, {3.519653090382893*^9, 
   3.5196530935340986`*^9}, {3.5196531791314487`*^9, 3.519653250173974*^9}, {
   3.5196532810152283`*^9, 3.5196532980192575`*^9}, {3.5196533325806475`*^9, 
   3.5196538112690268`*^9}, {3.5196538853022614`*^9, 3.519653890852578*^9}, {
   3.519654660230584*^9, 3.5196546604445963`*^9}, 3.519659549731248*^9, {
   3.5196600659707747`*^9, 3.5196600678128805`*^9}, {3.519660113400488*^9, 
   3.5196602219676976`*^9}, {3.519660259648853*^9, 3.5196602616169653`*^9}, {
   3.519660510173182*^9, 3.5196605105512037`*^9}}],

Cell["H5DEXTENDOPEN", "Text",
 CellChangeTimes->{{3.519660278460929*^9, 3.519660280948071*^9}}],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"H5DExtendOpen", ",", "HoldAll"}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.51934407062022*^9, 3.519344120024046*^9}, {
   3.51934615413139*^9, 3.519346196527815*^9}, {3.5193463071891446`*^9, 
   3.519346553786249*^9}, {3.5194247842480574`*^9, 3.5194247873542356`*^9}, {
   3.5194248180309896`*^9, 3.5194248370840797`*^9}, 3.519427366309743*^9, {
   3.519653122175749*^9, 3.519653129819762*^9}, 3.5196592377634044`*^9, 
   3.519659397356532*^9, 3.51965955343846*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5DExtendOpen", "[", 
   RowBox[{"groupOrFileIDspecification_List", ",", "body_"}], "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "output", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"With", "[", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"e", ".", "g", "."}], ",", " ", 
       RowBox[{"dataSetID", " ", "=", " ", 
        RowBox[{"H5DOpen", "[", 
         RowBox[{"...", "."}], "]"}]}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"groupOrFileIDspecification", ",", "\[IndentingNewLine]", 
      RowBox[{"With", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{"pickout", " ", "'"}], 
           RowBox[{"dataSetID", "'"}], " ", "from", " ", "user", " ", "input",
            " ", "and", " ", "insert", " ", "it", " ", "into", " ", "the", 
           " ", "statement", " ", "for", " ", "H5Dclose"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"dataSetIDsymbol", "=", 
          RowBox[{"Replace", "[", 
           RowBox[{
            RowBox[{"Hold", "[", "groupOrFileIDspecification", "]"}], ",", 
            RowBox[{
             RowBox[{"Hold", "[", 
              RowBox[{"List", "[", 
               RowBox[{"Set", "[", 
                RowBox[{
                 RowBox[{"symbol", ":", "_"}], ",", "_"}], "]"}], "]"}], 
              "]"}], "\[RuleDelayed]", " ", "symbol"}]}], "]"}]}], 
         "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "execute", " ", "the", " ", "main", " ", "body", " ", "and", " ", 
          "then", " ", "close", " ", "the", " ", "file"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"CompoundExpression", "[", 
         RowBox[{
          RowBox[{"output", "=", "body"}], ",", 
          RowBox[{"H5Dclose", "[", "dataSetIDsymbol", "]"}], ",", "output"}], 
         "]"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5191733398934135`*^9, 3.519173365854898*^9}, {
   3.519173446170492*^9, 3.51917344718355*^9}, {3.519173714830858*^9, 
   3.5191737306227617`*^9}, {3.5191739405427685`*^9, 3.51917397274761*^9}, {
   3.519176894147705*^9, 3.519176894256711*^9}, 3.5192053347354136`*^9, 
   3.519224813284523*^9, {3.5192248527497797`*^9, 3.5192248528837876`*^9}, 
   3.5192920674302397`*^9, 3.51929411701847*^9, 3.5192970476020894`*^9, {
   3.519315739314762*^9, 3.5193157412418723`*^9}, {3.5196517309029055`*^9, 
   3.5196518027722316`*^9}, {3.5196520714671035`*^9, 3.519652135895217*^9}, {
   3.519652452778573*^9, 3.5196524556645784`*^9}, {3.519653090382893*^9, 
   3.5196530935340986`*^9}, {3.5196531791314487`*^9, 3.519653250173974*^9}, {
   3.5196532810152283`*^9, 3.5196532980192575`*^9}, {3.5196533325806475`*^9, 
   3.5196538112690268`*^9}, {3.5196538853022614`*^9, 3.519653890852578*^9}, {
   3.519654660230584*^9, 3.5196546604445963`*^9}, 3.5196592544573593`*^9, {
   3.5196593251144004`*^9, 3.5196593911751785`*^9}, {3.519659572943576*^9, 
   3.519659674388378*^9}, {3.5196610640088596`*^9, 3.5196610865211473`*^9}}]
}, Closed]],

Cell["H5E", "Subsubsection",
 CellChangeTimes->{{3.519204542239085*^9, 3.519204543245143*^9}, 
   3.5192170693915977`*^9, 3.5192905945269947`*^9}],

Cell[CellGroupData[{

Cell["H5F", "Subsubsection",
 CellChangeTimes->{{3.519204494378348*^9, 3.5192044950903883`*^9}}],

Cell["H5FEXTENDOPEN", "Text",
 CellChangeTimes->{{3.519660305130454*^9, 3.519660308097624*^9}}],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"H5FExtendOpen", ",", "HoldAll"}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.51934407062022*^9, 3.519344120024046*^9}, {
   3.51934615413139*^9, 3.519346196527815*^9}, {3.5193463071891446`*^9, 
   3.519346553786249*^9}, {3.5194247842480574`*^9, 3.5194247873542356`*^9}, {
   3.5194248180309896`*^9, 3.5194248370840797`*^9}, 3.519427366309743*^9, {
   3.519653122175749*^9, 3.519653129819762*^9}, 3.5196592377634044`*^9, 
   3.519659397356532*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5FExtendOpen", "[", 
   RowBox[{"fileIDspecification_List", ",", "body_"}], "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "output", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"With", "[", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"e", ".", "g", "."}], ",", " ", 
       RowBox[{"fileID", " ", "=", " ", 
        RowBox[{"H5FOpen", "[", 
         RowBox[{"...", "."}], "]"}]}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"fileIDspecification", ",", "\[IndentingNewLine]", 
      RowBox[{"With", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{"pickout", " ", "'"}], 
           RowBox[{"fileID", "'"}], " ", "from", " ", "user", " ", "input", 
           " ", "and", " ", "insert", " ", "it", " ", "into", " ", "the", " ",
            "statement", " ", "for", " ", "H5Fclose"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"fileIDsymbol", "=", 
          RowBox[{"Replace", "[", 
           RowBox[{
            RowBox[{"Hold", "[", "fileIDspecification", "]"}], ",", 
            RowBox[{
             RowBox[{"Hold", "[", 
              RowBox[{"List", "[", 
               RowBox[{"Set", "[", 
                RowBox[{
                 RowBox[{"symbol", ":", "_"}], ",", "_"}], "]"}], "]"}], 
              "]"}], "\[RuleDelayed]", " ", "symbol"}]}], "]"}]}], 
         "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "execute", " ", "the", " ", "main", " ", "body", " ", "and", " ", 
          "then", " ", "close", " ", "the", " ", "file"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"CompoundExpression", "[", 
         RowBox[{
          RowBox[{"output", "=", "body"}], ",", 
          RowBox[{"H5Fclose", "[", "fileIDsymbol", "]"}], ",", "output"}], 
         "]"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5191733398934135`*^9, 3.519173365854898*^9}, {
   3.519173446170492*^9, 3.51917344718355*^9}, {3.519173714830858*^9, 
   3.5191737306227617`*^9}, {3.5191739405427685`*^9, 3.51917397274761*^9}, {
   3.519176894147705*^9, 3.519176894256711*^9}, 3.5192053347354136`*^9, 
   3.519224813284523*^9, {3.5192248527497797`*^9, 3.5192248528837876`*^9}, 
   3.5192920674302397`*^9, 3.51929411701847*^9, 3.5192970476020894`*^9, {
   3.519315739314762*^9, 3.5193157412418723`*^9}, {3.5196517309029055`*^9, 
   3.5196518027722316`*^9}, {3.5196520714671035`*^9, 3.519652135895217*^9}, {
   3.519652452778573*^9, 3.5196524556645784`*^9}, {3.519653090382893*^9, 
   3.5196530935340986`*^9}, {3.5196531791314487`*^9, 3.519653250173974*^9}, {
   3.5196532810152283`*^9, 3.5196532980192575`*^9}, {3.5196533325806475`*^9, 
   3.5196538112690268`*^9}, {3.5196538853022614`*^9, 3.519653890852578*^9}, {
   3.519654660230584*^9, 3.5196546604445963`*^9}, 3.5196592544573593`*^9, {
   3.5196593251144004`*^9, 3.5196593911751785`*^9}, 3.5196596173011127`*^9, {
   3.5196610921044664`*^9, 3.5196611049542017`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["H5G", "Subsubsection",
 CellChangeTimes->{{3.519204542239085*^9, 3.519204543245143*^9}}],

Cell["H5GEXTENDOPEN", "Text",
 CellChangeTimes->{{3.5196603132969213`*^9, 3.5196603155730515`*^9}}],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"H5GExtendOpen", ",", "HoldAll"}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4241685568125*^9, 3.42416856196875*^9}, {
   3.42416867778125*^9, 3.424168794828125*^9}, {3.424168888671875*^9, 
   3.4241688910625*^9}, {3.424168939953125*^9, 3.42416894265625*^9}, {
   3.4241690483125*^9, 3.424169048671875*^9}, {3.4241691644375*^9, 
   3.424169257890625*^9}, {3.4241692955625*^9, 3.424169333625*^9}, 
   3.42429194584375*^9, {3.42429201525*^9, 3.424292039703125*^9}, {
   3.42531231896875*^9, 3.42531231971875*^9}, {3.42531610275*^9, 
   3.425316199015625*^9}, {3.425318000046875*^9, 3.42531805809375*^9}, {
   3.425318259375*^9, 3.425318273125*^9}, 3.439553691296875*^9, {
   3.45596566134375*^9, 3.4559656830625*^9}, {3.455965715453125*^9, 
   3.455965726609375*^9}, {3.457613179578125*^9, 3.45761324940625*^9}, {
   3.457613361765625*^9, 3.457613363*^9}, 3.457613551421875*^9, {
   3.457995227921875*^9, 3.457995260140625*^9}, {3.45799532221875*^9, 
   3.457995408046875*^9}, {3.457997069265625*^9, 3.45799713934375*^9}, {
   3.45799732821875*^9, 3.457997370828125*^9}, {3.465143749546875*^9, 
   3.465143774*^9}, {3.472653393078125*^9, 3.472653406375*^9}, {
   3.482442139213971*^9, 3.482442186731655*^9}, {3.4824463066364913`*^9, 
   3.4824463225173187`*^9}, {3.48244636303059*^9, 3.4824464241982975`*^9}, {
   3.487324745914733*^9, 3.487324753137546*^9}, {3.487325636379897*^9, 
   3.487325713022832*^9}, {3.4873258377294507`*^9, 3.487325844640263*^9}, {
   3.4873265059722247`*^9, 3.4873265189670477`*^9}, {3.487326657854091*^9, 
   3.4873266620192986`*^9}, {3.4873269408073883`*^9, 
   3.4873270133787155`*^9}, {3.487327379277358*^9, 3.487327427933844*^9}, {
   3.487327495091962*^9, 3.487327519147204*^9}, {3.487327568490091*^9, 
   3.4873275691764917`*^9}, {3.4873428881397915`*^9, 
   3.4873429114150324`*^9}, {3.487356278767722*^9, 3.4873563123077807`*^9}, {
   3.4873565797078505`*^9, 3.4873566167735157`*^9}, {3.487356939600483*^9, 
   3.48735702338823*^9}, {3.48735720004294*^9, 3.4873572153153667`*^9}, {
   3.487357271163465*^9, 3.4873573539528103`*^9}, {3.487359187957632*^9, 
   3.487359201966457*^9}, {3.4874953406867576`*^9, 3.487495363088397*^9}, {
   3.487496065682431*^9, 3.48749619612986*^9}, {3.4874967416160183`*^9, 
   3.4874967481992297`*^9}, {3.4874968534214144`*^9, 3.487496920875933*^9}, 
   3.4874970514013624`*^9, {3.487523369899844*^9, 3.4875234301939507`*^9}, {
   3.487523862049509*^9, 3.4875238651071143`*^9}, {3.487523942904451*^9, 
   3.4875240392658205`*^9}, {3.4875255047339945`*^9, 
   3.4875255122688074`*^9}, {3.4887477010560827`*^9, 3.488747846619939*^9}, 
   3.488748087187961*^9, {3.488748118403616*^9, 3.488748118793617*^9}, {
   3.4911430657451982`*^9, 3.491143142559733*^9}, {3.4911592169547653`*^9, 
   3.49115921955997*^9}, {3.4911593632362223`*^9, 3.491159381597455*^9}, {
   3.5186029186651335`*^9, 3.5186029685479865`*^9}, 3.5186030601162243`*^9, {
   3.519335097808005*^9, 3.519335103118308*^9}, {3.5193354635439234`*^9, 
   3.51933546575305*^9}, {3.51934407062022*^9, 3.519344120024046*^9}, {
   3.51934615413139*^9, 3.519346196527815*^9}, {3.5193463071891446`*^9, 
   3.519346553786249*^9}, {3.5194247842480574`*^9, 3.5194247873542356`*^9}, {
   3.5194248180309896`*^9, 3.5194248370840797`*^9}, 3.519427366309743*^9, {
   3.519653122175749*^9, 3.519653129819762*^9}, 3.5196592377634044`*^9, 
   3.519659397356532*^9, 3.51965955343846*^9, 3.5196598720186815`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5GExtendOpen", "[", 
   RowBox[{"groupOrFileIDspecification_List", ",", "body_"}], "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "output", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"With", "[", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"e", ".", "g", "."}], ",", " ", 
       RowBox[{"dataSetID", " ", "=", " ", 
        RowBox[{"H5DOpen", "[", 
         RowBox[{"...", "."}], "]"}]}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"groupOrFileIDspecification", ",", "\[IndentingNewLine]", 
      RowBox[{"With", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{"pickout", " ", "'"}], 
           RowBox[{"dataSetID", "'"}], " ", "from", " ", "user", " ", "input",
            " ", "and", " ", "insert", " ", "it", " ", "into", " ", "the", 
           " ", "statement", " ", "for", " ", "H5Dclose"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"groupIDsymbol", "=", 
          RowBox[{"Replace", "[", 
           RowBox[{
            RowBox[{"Hold", "[", "groupOrFileIDspecification", "]"}], ",", 
            RowBox[{
             RowBox[{"Hold", "[", 
              RowBox[{"List", "[", 
               RowBox[{"Set", "[", 
                RowBox[{
                 RowBox[{"symbol", ":", "_"}], ",", "_"}], "]"}], "]"}], 
              "]"}], "\[RuleDelayed]", " ", "symbol"}]}], "]"}]}], 
         "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "execute", " ", "the", " ", "main", " ", "body", " ", "and", " ", 
          "then", " ", "close", " ", "the", " ", "file"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"CompoundExpression", "[", 
         RowBox[{
          RowBox[{"output", "=", "body"}], ",", 
          RowBox[{"H5Gclose", "[", "groupIDsymbol", "]"}], ",", "output"}], 
         "]"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5191733398934135`*^9, 3.519173365854898*^9}, {
   3.519173446170492*^9, 3.51917344718355*^9}, {3.519173714830858*^9, 
   3.5191737306227617`*^9}, {3.5191739405427685`*^9, 3.51917397274761*^9}, {
   3.519176894147705*^9, 3.519176894256711*^9}, 3.5192053347354136`*^9, 
   3.519224813284523*^9, {3.5192248527497797`*^9, 3.5192248528837876`*^9}, 
   3.5192920674302397`*^9, 3.51929411701847*^9, 3.5192970476020894`*^9, {
   3.519315739314762*^9, 3.5193157412418723`*^9}, {3.5196517309029055`*^9, 
   3.5196518027722316`*^9}, {3.5196520714671035`*^9, 3.519652135895217*^9}, {
   3.519652452778573*^9, 3.5196524556645784`*^9}, {3.519653090382893*^9, 
   3.5196530935340986`*^9}, {3.5196531791314487`*^9, 3.519653250173974*^9}, {
   3.5196532810152283`*^9, 3.5196532980192575`*^9}, {3.5196533325806475`*^9, 
   3.5196538112690268`*^9}, {3.5196538853022614`*^9, 3.519653890852578*^9}, {
   3.519654660230584*^9, 3.5196546604445963`*^9}, 3.5196592544573593`*^9, {
   3.5196593251144004`*^9, 3.5196593911751785`*^9}, {3.519659572943576*^9, 
   3.519659674388378*^9}, 3.5196598739647927`*^9, {3.5196599264107924`*^9, 
   3.519659930769042*^9}, {3.519661112374626*^9, 3.519661124847339*^9}, 
   3.5196616367366176`*^9}],

Cell["H5GEXTENDGETNUMOBJS", "Text",
 CellChangeTimes->{{3.5196602954469004`*^9, 3.5196602993621244`*^9}, {
   3.5198326026253967`*^9, 3.51983260285441*^9}, {3.5198326892213497`*^9, 
   3.519832692426533*^9}, 3.5198328461423254`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5GExtendGetNumObjs", "[", "GroupOrFileID_Integer", "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"num", "=", "0"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"CompoundExpression", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"H5GgetNumObjs", "[", 
       RowBox[{"GroupOrFileID", ",", "num"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", "return", "*)"}], " ", "num"}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5191733398934135`*^9, 3.519173365854898*^9}, {
   3.519173446170492*^9, 3.51917344718355*^9}, {3.519173714830858*^9, 
   3.5191737306227617`*^9}, {3.5191739405427685`*^9, 3.51917397274761*^9}, {
   3.519176894147705*^9, 3.519176894256711*^9}, 3.5192053347354136`*^9, 
   3.519224813284523*^9, {3.5192248527497797`*^9, 3.5192248528837876`*^9}, 
   3.5192920674302397`*^9, 3.51929411701847*^9, 3.5192970476020894`*^9, {
   3.519315739314762*^9, 3.5193157412418723`*^9}, {3.5196517309029055`*^9, 
   3.5196518027722316`*^9}, {3.519832626790779*^9, 3.5198326864741926`*^9}, 
   3.5198328450482626`*^9}],

Cell["H5GEXTENDGETOBJNAMEBYINDEX", "Text",
 CellChangeTimes->{{3.5196602954469004`*^9, 3.5196602993621244`*^9}, {
   3.5198326026253967`*^9, 3.51983260285441*^9}, {3.5198326892213497`*^9, 
   3.519832692426533*^9}, 3.5198328461423254`*^9, {3.519833958268935*^9, 
   3.5198339657833652`*^9}, {3.5198340174583206`*^9, 3.519834018644388*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5GExtendGetObjNameByIndex", "[", 
   RowBox[{"GroupOrFileID_Integer", ",", "index_Integer"}], "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"NETBlock", "[", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"size", "=", 
       RowBox[{
        RowBox[{"H5GgetObjNameByIndex", "[", 
         RowBox[{"GroupOrFileID", ",", "index", ",", "Null", ",", "0"}], 
         "]"}], "+", "1"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"buffer", "=", 
         RowBox[{"NETNew", "[", 
          RowBox[{"\"\<System.Text.StringBuilder\>\"", ",", "size"}], "]"}]}],
         "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"CompoundExpression", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"H5GgetObjNameByIndex", "[", 
          RowBox[{"GroupOrFileID", ",", "index", ",", "buffer", ",", "size"}],
           "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"(*", "return", "*)"}], "  ", 
         RowBox[{"buffer", "@", 
          RowBox[{"ToString", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
      "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5191733398934135`*^9, 3.519173365854898*^9}, {
   3.519173446170492*^9, 3.51917344718355*^9}, {3.519173714830858*^9, 
   3.5191737306227617`*^9}, {3.5191739405427685`*^9, 3.51917397274761*^9}, {
   3.519176894147705*^9, 3.519176894256711*^9}, 3.5192053347354136`*^9, 
   3.519224813284523*^9, {3.5192248527497797`*^9, 3.5192248528837876`*^9}, 
   3.5192920674302397`*^9, 3.51929411701847*^9, 3.5192970476020894`*^9, {
   3.519315739314762*^9, 3.5193157412418723`*^9}, {3.5196517309029055`*^9, 
   3.5196518027722316`*^9}, {3.519832626790779*^9, 3.5198326864741926`*^9}, 
   3.5198328450482626`*^9, 3.519833959281993*^9, {3.5198340205965*^9, 
   3.519834024329714*^9}, {3.519834095042758*^9, 3.519834170849094*^9}, {
   3.519849372081555*^9, 3.519849407149561*^9}, {3.5198495953103228`*^9, 
   3.5198495956413417`*^9}}]
}, Closed]],

Cell["H5I", "Subsubsection",
 CellChangeTimes->{{3.519204542239085*^9, 3.519204543245143*^9}, 
   3.5192414597096443`*^9}],

Cell["H5L", "Subsubsection",
 CellChangeTimes->{{3.519204542239085*^9, 3.519204543245143*^9}, 
   3.5192170693915977`*^9, {3.5192906033064966`*^9, 3.5192906035985136`*^9}}],

Cell["H5O", "Subsubsection",
 CellChangeTimes->{{3.519204542239085*^9, 3.519204543245143*^9}, 
   3.5192170693915977`*^9, {3.5192906075127373`*^9, 3.5192906077527514`*^9}}],

Cell["H5P", "Subsubsection",
 CellChangeTimes->{{3.519204542239085*^9, 3.519204543245143*^9}, 
   3.5192170693915977`*^9, {3.5192906148501573`*^9, 3.519290615140174*^9}}],

Cell["H5R", "Subsubsection",
 CellChangeTimes->{{3.519204542239085*^9, 3.519204543245143*^9}, 
   3.5192170693915977`*^9, {3.519290621344528*^9, 3.519290621564541*^9}}],

Cell[CellGroupData[{

Cell["H5S", "Subsubsection",
 CellChangeTimes->{{3.519204542239085*^9, 3.519204543245143*^9}, 
   3.5192170693915977`*^9, 3.5192171456419587`*^9}],

Cell["H5SEXTENDGETSIMPLEEXTENTDIMS", "Text",
 CellChangeTimes->{{3.519660321159371*^9, 3.519660326136656*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H5SExtendGetSimpleExtentDims", "[", "dataSpaceID_Integer", "]"}], ":=",
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"NETBlock", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dataSpaceDimensionsObject", "=", 
       RowBox[{"NETNew", "[", 
        RowBox[{"\"\<System.Int64[]\>\"", ",", 
         RowBox[{"H5SgetSimpleExtentNDims", "@", "dataSpaceID"}]}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"CompoundExpression", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"H5SgetSimpleExtentDims", "[", 
        RowBox[{
        "dataSpaceID", ",", "dataSpaceDimensionsObject", ",", "Null"}], "]"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "return", "*)"}], " ", 
       RowBox[{"NETObjectToExpression", "@", "dataSpaceDimensionsObject"}]}], 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5191733398934135`*^9, 3.519173365854898*^9}, {
   3.519173446170492*^9, 3.51917344718355*^9}, {3.519173714830858*^9, 
   3.5191737306227617`*^9}, {3.5191739405427685`*^9, 3.51917397274761*^9}, {
   3.519176894147705*^9, 3.519176894256711*^9}, 3.5192053347354136`*^9, 
   3.519224813284523*^9, {3.5192248527497797`*^9, 3.5192248528837876`*^9}, 
   3.5192920674302397`*^9, 3.51929411701847*^9, 3.5192970476020894`*^9, {
   3.519315739314762*^9, 3.5193157412418723`*^9}, {3.5196517309029055`*^9, 
   3.5196518027722316`*^9}, {3.5196520714671035`*^9, 3.519652135895217*^9}, {
   3.519652452778573*^9, 3.5196524556645784`*^9}}]
}, Closed]],

Cell["H5T", "Subsubsection",
 CellChangeTimes->{{3.519204542239085*^9, 3.519204543245143*^9}, 
   3.5192170693915977`*^9, 3.519217142155759*^9}],

Cell["H5Z", "Subsubsection",
 CellChangeTimes->{{3.519204542239085*^9, 3.519204543245143*^9}, 
   3.5192170693915977`*^9, {3.51929062976001*^9, 3.519290630308041*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["End Private", "Subsection",
 CellChangeTimes->{{3.5196620682102966`*^9, 3.5196620693433614`*^9}}],

Cell[BoxData[
 RowBox[{"End", "[", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.408031040171875*^9, 3.40803104709375*^9}, {
   3.40809723659375*^9, 3.40809724321875*^9}, {3.408098192359375*^9, 
   3.40809819740625*^9}, {3.4220205259375*^9, 3.422020529390625*^9}, {
   3.424166725765625*^9, 3.4241667264375*^9}, {3.424167071765625*^9, 
   3.4241670748125*^9}, {3.42416796359375*^9, 3.42416796425*^9}, {
   3.4241685774375*^9, 3.424168579078125*^9}, 3.4241688833125*^9, {
   3.4243731498611765`*^9, 3.4243731502049265`*^9}, {3.4243826396265*^9, 
   3.424382640204625*^9}, {3.42487181125*^9, 3.424871812359375*^9}, {
   3.424896963640625*^9, 3.4248969688125*^9}, {3.424947306109375*^9, 
   3.424947307375*^9}, {3.425300354703125*^9, 3.425300355453125*^9}, {
   3.42531630675*^9, 3.425316307296875*^9}, {3.426085914125*^9, 
   3.426085915515625*^9}, {3.426260020776*^9, 3.42626002230725*^9}, 
   3.426260427479125*^9, {3.42669741525*^9, 3.42669741625*^9}, {
   3.42688123678125*^9, 3.42688123846875*^9}, {3.427301184828125*^9, 
   3.4273011860625*^9}, {3.42748432184375*^9, 3.427484322703125*^9}, 
   3.42758353790625*^9, {3.427749714421875*^9, 3.42774972146875*^9}, {
   3.430080750140625*^9, 3.43008075296875*^9}, {3.43414707978125*^9, 
   3.43414708190625*^9}, {3.439485637984375*^9, 3.43948563834375*^9}, {
   3.44062046115625*^9, 3.44062046196875*^9}, 3.4455516160625*^9, {
   3.445807115984375*^9, 3.445807117640625*^9}, {3.445808939234375*^9, 
   3.445808939796875*^9}, {3.45209927690625*^9, 3.45209927734375*^9}, {
   3.452101782765625*^9, 3.4521017838125*^9}, {3.45211392121875*^9, 
   3.45211392146875*^9}, {3.4521141260625*^9, 3.452114131515625*^9}, {
   3.452115581078125*^9, 3.4521155849375*^9}, {3.45216627284375*^9, 
   3.452166274625*^9}, {3.45460755846875*^9, 3.4546075789375*^9}, {
   3.4548444485*^9, 3.454844458265625*^9}, {3.45484460528125*^9, 
   3.454844616609375*^9}, {3.454845229078125*^9, 3.45484524890625*^9}, {
   3.4548457654375*^9, 3.454845770609375*^9}, {3.454845837734375*^9, 
   3.454845838*^9}, {3.454847184140625*^9, 3.45484718515625*^9}, {
   3.4558972838125*^9, 3.45589728459375*^9}, {3.45589824390625*^9, 
   3.455898244609375*^9}, {3.45590782150525*^9, 3.4559078224115*^9}, {
   3.4559086504115*^9, 3.4559086516615*^9}, {3.4564321404375*^9, 
   3.456432143703125*^9}, {3.45696166040625*^9, 3.456961660734375*^9}, {
   3.45700658125*^9, 3.4570065815625*^9}, {3.4574717149375*^9, 
   3.457471719046875*^9}, {3.45764546525*^9, 3.457645465546875*^9}, 
   3.46507809478125*^9, 3.5186034623562307`*^9, {3.5186045077640247`*^9, 
   3.518604507997038*^9}, {3.519427404878949*^9, 3.5194274457942896`*^9}, {
   3.5196592945736537`*^9, 3.51965931775698*^9}, {3.519661607595951*^9, 
   3.5196616273500805`*^9}, {3.519662111860793*^9, 3.5196621123538218`*^9}}],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "H5ExtendGetUlibVersion", ",", "H5DExtendRead", ",", "H5DExtendWrite", 
     ",", "H5DExtendOpen", ",", "H5FExtendOpen", ",", "H5GExtendOpen", ",", 
     "H5SExtendGetSimpleExtentDims", ",", "H5GExtendGetNumObjs", ",", 
     "H5GExtendGetObjNameByIndex", ",", "H5AExtendGetName", ",", 
     "H5AExtendRead"}], "}"}], ",", "\[IndentingNewLine]", "ReadProtected"}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.408031040171875*^9, 3.40803104709375*^9}, {
   3.40809723659375*^9, 3.40809724321875*^9}, {3.408098192359375*^9, 
   3.40809819740625*^9}, {3.4220205259375*^9, 3.422020529390625*^9}, {
   3.424166725765625*^9, 3.4241667264375*^9}, {3.424167071765625*^9, 
   3.4241670748125*^9}, {3.42416796359375*^9, 3.42416796425*^9}, {
   3.4241685774375*^9, 3.424168579078125*^9}, 3.4241688833125*^9, {
   3.4243731498611765`*^9, 3.4243731502049265`*^9}, {3.4243826396265*^9, 
   3.424382640204625*^9}, {3.42487181125*^9, 3.424871812359375*^9}, {
   3.424896963640625*^9, 3.4248969688125*^9}, {3.424947306109375*^9, 
   3.424947307375*^9}, {3.425300354703125*^9, 3.425300355453125*^9}, {
   3.42531630675*^9, 3.425316307296875*^9}, {3.426085914125*^9, 
   3.426085915515625*^9}, {3.426260020776*^9, 3.42626002230725*^9}, 
   3.426260427479125*^9, {3.42669741525*^9, 3.42669741625*^9}, {
   3.42688123678125*^9, 3.42688123846875*^9}, {3.427301184828125*^9, 
   3.4273011860625*^9}, {3.42748432184375*^9, 3.427484322703125*^9}, 
   3.42758353790625*^9, {3.427749714421875*^9, 3.42774972146875*^9}, {
   3.430080750140625*^9, 3.43008075296875*^9}, {3.43414707978125*^9, 
   3.43414708190625*^9}, {3.439485637984375*^9, 3.43948563834375*^9}, {
   3.44062046115625*^9, 3.44062046196875*^9}, 3.4455516160625*^9, {
   3.445807115984375*^9, 3.445807117640625*^9}, {3.445808939234375*^9, 
   3.445808939796875*^9}, {3.45209927690625*^9, 3.45209927734375*^9}, {
   3.452101782765625*^9, 3.4521017838125*^9}, {3.45211392121875*^9, 
   3.45211392146875*^9}, {3.4521141260625*^9, 3.452114131515625*^9}, {
   3.452115581078125*^9, 3.4521155849375*^9}, {3.45216627284375*^9, 
   3.452166274625*^9}, {3.45460755846875*^9, 3.4546075789375*^9}, {
   3.4548444485*^9, 3.454844458265625*^9}, {3.45484460528125*^9, 
   3.454844616609375*^9}, {3.454845229078125*^9, 3.45484524890625*^9}, {
   3.4548457654375*^9, 3.454845770609375*^9}, {3.454845837734375*^9, 
   3.454845838*^9}, {3.454847184140625*^9, 3.45484718515625*^9}, {
   3.4558972838125*^9, 3.45589728459375*^9}, {3.45589824390625*^9, 
   3.455898244609375*^9}, {3.45590782150525*^9, 3.4559078224115*^9}, {
   3.4559086504115*^9, 3.4559086516615*^9}, {3.4564321404375*^9, 
   3.456432143703125*^9}, {3.45696166040625*^9, 3.456961660734375*^9}, {
   3.45700658125*^9, 3.4570065815625*^9}, {3.4574717149375*^9, 
   3.457471719046875*^9}, {3.45764546525*^9, 3.457645465546875*^9}, 
   3.46507809478125*^9, 3.5186034623562307`*^9, {3.5186045077640247`*^9, 
   3.518604507997038*^9}, {3.519427404878949*^9, 3.5194274457942896`*^9}, {
   3.5196592945736537`*^9, 3.51965931775698*^9}, {3.519661607595951*^9, 
   3.5196616273500805`*^9}, {3.5198488956163025`*^9, 
   3.5198489058098855`*^9}, {3.519848970143565*^9, 3.5198489704755845`*^9}, {
   3.519854988505796*^9, 3.519854988779812*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["EndPackage Context[...]", "Subsection",
 CellChangeTimes->{{3.5192918468206215`*^9, 3.5192918525209475`*^9}}],

Cell[BoxData[
 RowBox[{"EndPackage", "[", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.457546165609375*^9, 3.457546171265625*^9}, {
   3.457546207015625*^9, 3.457546220796875*^9}, {3.45799610640625*^9, 
   3.45799611634375*^9}, {3.468963528828125*^9, 3.4689635290625*^9}, {
   3.4823496125557427`*^9, 3.48234961459686*^9}, 3.489017891677415*^9, {
   3.5186009153340993`*^9, 3.518600938016539*^9}, {3.5186010187466807`*^9, 
   3.5186010191366816`*^9}, {3.5186011517993145`*^9, 3.518601152251715*^9}, {
   3.5192915927500896`*^9, 3.519291593252118*^9}, {3.5192916330783963`*^9, 
   3.519291646919188*^9}}]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{1492, 1001},
WindowMargins->{{Automatic, 6}, {Automatic, 18}},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.5, 1.5 Inherited],
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 98, 1, 105, "Section"],
Cell[680, 25, 812, 17, 90, "Text"],
Cell[1495, 44, 383, 8, 41, "Text"],
Cell[1881, 54, 1049, 22, 90, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2967, 81, 92, 1, 105, "Section"],
Cell[CellGroupData[{
Cell[3084, 86, 114, 1, 54, "Subsection"],
Cell[3201, 89, 875, 15, 43, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[4113, 109, 103, 1, 40, "Subsection"],
Cell[4219, 112, 1023, 15, 43, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[5279, 132, 104, 1, 40, "Subsection"],
Cell[5386, 135, 3334, 49, 71, "Input",
 InitializationCell->True],
Cell[8723, 186, 3417, 50, 71, "Input",
 InitializationCell->True],
Cell[12143, 238, 4354, 62, 233, "Input",
 InitializationCell->True],
Cell[16500, 302, 4154, 60, 206, "Input",
 InitializationCell->True],
Cell[20657, 364, 3862, 55, 125, "Input",
 InitializationCell->True],
Cell[24522, 421, 3849, 55, 125, "Input",
 InitializationCell->True],
Cell[28374, 478, 3808, 55, 125, "Input",
 InitializationCell->True],
Cell[32185, 535, 3810, 55, 71, "Input",
 InitializationCell->True],
Cell[35998, 592, 3953, 58, 98, "Input",
 InitializationCell->True],
Cell[39954, 652, 3946, 57, 71, "Input",
 InitializationCell->True],
Cell[43903, 711, 4348, 62, 125, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[48288, 778, 164, 2, 40, "Subsection"],
Cell[48455, 782, 812, 12, 43, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[49292, 798, 97, 1, 38, "Subsubsection"],
Cell[49392, 801, 108, 1, 61, "Text"],
Cell[49503, 804, 1419, 29, 511, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[50959, 838, 124, 2, 27, "Subsubsection"],
Cell[51086, 842, 380, 5, 41, "Text"],
Cell[51469, 849, 2179, 42, 314, "Input",
 InitializationCell->True],
Cell[53651, 893, 121, 2, 41, "Text"],
Cell[53775, 897, 3532, 53, 71, "Input",
 InitializationCell->True],
Cell[57310, 952, 5972, 117, 1178, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[63319, 1074, 122, 2, 27, "Subsubsection"],
Cell[63444, 1078, 95, 1, 41, "Text"],
Cell[63542, 1081, 3508, 53, 71, "Input",
 InitializationCell->True],
Cell[67053, 1136, 5988, 118, 1232, "Input",
 InitializationCell->True],
Cell[73044, 1256, 100, 1, 41, "Text"],
Cell[73147, 1259, 3561, 54, 71, "Input",
 InitializationCell->True],
Cell[76711, 1315, 2135, 40, 179, "Input",
 InitializationCell->True],
Cell[78849, 1357, 95, 1, 41, "Text"],
Cell[78947, 1360, 3473, 50, 43, "Input",
 InitializationCell->True],
Cell[82423, 1412, 3399, 65, 503, "Input",
 InitializationCell->True]
}, Closed]],
Cell[85837, 1480, 146, 2, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[86008, 1486, 96, 1, 27, "Subsubsection"],
Cell[86107, 1489, 95, 1, 61, "Text"],
Cell[86205, 1492, 3452, 50, 64, "Input",
 InitializationCell->True],
Cell[89660, 1544, 3344, 65, 754, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[93041, 1614, 94, 1, 27, "Subsubsection"],
Cell[93138, 1617, 99, 1, 41, "Text"],
Cell[93240, 1620, 3497, 50, 43, "Input",
 InitializationCell->True],
Cell[96740, 1672, 3495, 67, 503, "Input",
 InitializationCell->True],
Cell[100238, 1741, 232, 3, 41, "Text"],
Cell[100473, 1746, 1353, 25, 341, "Input",
 InitializationCell->True],
Cell[101829, 1773, 339, 4, 41, "Text"],
Cell[102171, 1779, 2157, 42, 314, "Input",
 InitializationCell->True]
}, Closed]],
Cell[104343, 1824, 122, 2, 27, "Subsubsection"],
Cell[104468, 1828, 172, 2, 27, "Subsubsection"],
Cell[104643, 1832, 172, 2, 27, "Subsubsection"],
Cell[104818, 1836, 170, 2, 27, "Subsubsection"],
Cell[104991, 1840, 168, 2, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[105184, 1846, 146, 2, 27, "Subsubsection"],
Cell[105333, 1850, 110, 1, 61, "Text"],
Cell[105446, 1853, 1826, 33, 673, "Input",
 InitializationCell->True]
}, Closed]],
Cell[107287, 1889, 144, 2, 27, "Subsubsection"],
Cell[107434, 1893, 167, 2, 27, "Subsubsection"]
}, Closed]],
Cell[CellGroupData[{
Cell[107638, 1900, 103, 1, 40, "Subsection"],
Cell[107744, 1903, 2803, 41, 43, "Input",
 InitializationCell->True],
Cell[110550, 1946, 3376, 52, 152, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[113963, 2003, 115, 1, 40, "Subsection"],
Cell[114081, 2006, 624, 10, 43, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
